package View;

import android.content.Intent;
import android.os.Bundle;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import androidx.activity.EdgeToEdge;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.graphics.Insets;
import androidx.core.view.ViewCompat;
import androidx.core.view.WindowInsetsCompat;

import com.example.habittracker.R;

import Database.DatabaseHelper;
import Model.User;

public class MainActivity extends AppCompatActivity {

    Button loginBtn;
    EditText usernameEt;
    EditText passwordEt;
    TextView createAccountTv;
    DatabaseHelper db;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        EdgeToEdge.enable(this);
        setContentView(R.layout.activity_main);
        ViewCompat.setOnApplyWindowInsetsListener(findViewById(R.id.main), (v, insets) -> {
            Insets systemBars = insets.getInsets(WindowInsetsCompat.Type.systemBars());
            v.setPadding(systemBars.left, systemBars.top, systemBars.right, systemBars.bottom);
            return insets;
        });

        loginBtn = findViewById(R.id.login_btn);
        usernameEt = findViewById(R.id.username_et);
        passwordEt = findViewById(R.id.password_et);
        createAccountTv = findViewById(R.id.create_account_tv);
        db = new DatabaseHelper(MainActivity.this);

        //Opens create Account activity
        createAccountTv.setOnClickListener(v -> {
            Intent intent = new Intent(this, CreateAccountActivity.class);
            startActivity(intent);
        });


        loginBtn.setOnClickListener(v -> {
            if (usernameEt.getText().toString().isEmpty() || passwordEt.getText().toString().isEmpty()) {
                Toast.makeText(this, "Please enter the credentials", Toast.LENGTH_SHORT).show();
            } else {
                User user = login();
                if(user != null) {
                    Toast.makeText(this, "Authentication Success!", Toast.LENGTH_SHORT).show();
                    Intent intent = new Intent(this, HomeActivity.class);
                    intent.putExtra("UserId", user.getUserId());
                    intent.putExtra("Username", user.getUsername());
                    intent.putExtra("Password", user.getPassword());
                    startActivity(intent);
                }else {
                    Toast.makeText(this, "Authentication Failed!", Toast.LENGTH_SHORT).show();
                }
            }
        });

    }

    private User login() {
        return db.login(usernameEt.getText().toString(), passwordEt.getText().toString());
    }
}